local function clone_paq()
    local path = vim.fn.stdpath "data" .. "/site/pack/paqs/start/paq-nvim"
    local is_installed = vim.fn.empty(vim.fn.glob(path)) == 0
    if not is_installed then
        vim.fn.system {
            "git",
            "clone",
            "--depth",
            "1",
            "https://github.com/savq/paq-nvim.git",
            path,
        }
        return true
    end
end

local function bootstrap_paq(packages)
    local first_install = clone_paq()
    local paq = require("paq")

    paq(packages)
    vim.cmd("packadd paq-nvim")

    if first_install then
        paq.install()
    end
end

bootstrap_paq {
    "savq/paq-nvim",
    "nvim-lua/plenary.nvim",
    "lewis6991/gitsigns.nvim",
    "kyazdani42/nvim-web-devicons",
    "lukas-reineke/indent-blankline.nvim",
    "nvim-lualine/lualine.nvim",
    "windwp/nvim-autopairs",
    "mickael-menu/zk-nvim",
    { "nvim-telescope/telescope.nvim",            branch = "0.1.x" },
    { "nvim-telescope/telescope-fzf-native.nvim", run = "make" },
    { "catppuccin/nvim",                          as = "catppuccin" },
    { "williamboman/mason.nvim",                  branch = "v1.6.0" },
    { "lukas-reineke/lsp-format.nvim",            branch = "v2.5.1" },
    { "nvim-treesitter/nvim-treesitter",          branch = "master" },
    "nvim-treesitter/playground",
    "nvim-treesitter/nvim-treesitter-textobjects",
    "nvim-treesitter/nvim-treesitter-context",
    "stevearc/oil.nvim",
    "neovim/nvim-lspconfig",
    "hrsh7th/nvim-cmp",
    "hrsh7th/cmp-nvim-lsp",
    "hrsh7th/cmp-buffer",
    "hrsh7th/cmp-path",
    "hrsh7th/cmp-cmdline",
    "L3MON4D3/LuaSnip",
    "nvim-lua/lsp-status.nvim",
    "onsails/lspkind.nvim",
}
